@@ -13,8 +13,11 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
      time1 <- proc.time()
      ### Initial Checks
      cat("\nPerforming initial checks...\n")
-     if(is.null(Model)) stop("ERROR: A function must be entered for Model.")
-     if(is.null(Data)) stop("ERROR: A list containing data must be entered for Data.")
+     if(is.null(Model)) stop("A function must be entered for Model.")
+     if(is.null(Data)) stop("A list containing data must be entered for Data.")
+     if(is.null(Initial.Values)) {
+          cat("WARNING: Initial Values were not supplied, and are set to zero.")
+          Initial.Values <- rep(0, Data$parm.names)}
      if(Iterations < 11) {
           Iterations <- 11
           cat("'Iterations' has been changed to ", Iterations, ".\n",
@@ -39,15 +42,15 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
      ### Initial Settings
      Acceptance <- 0
      Mo0 <- Model(Initial.Values, Data)
-     if(is.na(Mo0[[1]])) stop("Error: The posterior is a missing value!")
-     if(is.infinite(Mo0[[1]])) stop("Error: The posterior is infinite!")
-     if(is.nan(Mo0[[1]])) stop("Error: The posterior was not a number!")
-     if(is.na(Mo0[[2]])) stop("Error: The deviance is a missing value!")
-     if(is.infinite(Mo0[[2]])) stop("Error: The deviance is infinite!")
-     if(is.nan(Mo0[[2]])) stop("Error: The deviance is not a number!")
-     if(sum(is.na(Mo0[[3]])) > 0) stop("Error: Monitored variable(s) have a missing value!")
-     if(sum(is.infinite(Mo0[[3]])) > 0) stop("Error: Monitored variable(s) have an infinite value!")
-     if(sum(is.nan(Mo0[[3]])) > 0) stop("Error: Monitored variable(s) include a value that is not a number!")
+     if(is.na(Mo0[[1]])) stop("The posterior is a missing value!")
+     if(is.infinite(Mo0[[1]])) stop("The posterior is infinite!")
+     if(is.nan(Mo0[[1]])) stop("The posterior was not a number!")
+     if(is.na(Mo0[[2]])) stop("The deviance is a missing value!")
+     if(is.infinite(Mo0[[2]])) stop("The deviance is infinite!")
+     if(is.nan(Mo0[[2]])) stop("The deviance is not a number!")
+     if(sum(is.na(Mo0[[3]])) > 0) stop("Monitored variable(s) have a missing value!")
+     if(sum(is.infinite(Mo0[[3]])) > 0) stop("Monitored variable(s) have an infinite value!")
+     if(sum(is.nan(Mo0[[3]])) > 0) stop("Monitored variable(s) include a value that is not a number!")
      Dev <- Mo0[[2]]
      Mon <- Mo0[[3]]
      LIV <- length(Initial.Values)
@@ -90,15 +93,15 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
           post[iter+1,] <- post[iter,]
           ### Log-Posterior of the current state
           Mo0 <- Model(post[iter,], Data)
-          if(is.na(Mo0[[1]])) stop("Error: The posterior is a missing value!")
-          if(is.infinite(Mo0[[1]])) stop("Error: The posterior is infinite!")
-          if(is.nan(Mo0[[1]])) stop("Error: The posterior was not a number!")
-          if(is.na(Mo0[[2]])) stop("Error: The deviance is a missing value!")
-          if(is.infinite(Mo0[[2]])) stop("Error: The deviance is infinite!")
-          if(is.nan(Mo0[[2]])) stop("Error: The deviance is not a number!")
-          if(sum(is.na(Mo0[[3]])) > 0) stop("Error: Monitored variable(s) have a missing value!")
-          if(sum(is.infinite(Mo0[[3]])) > 0) stop("Error: Monitored variable(s) have an infinite value!")
-          if(sum(is.nan(Mo0[[3]])) > 0) stop("Error: Monitored variable(s) include a value that is not a number!")
+          if(is.na(Mo0[[1]])) stop("The posterior is a missing value!")
+          if(is.infinite(Mo0[[1]])) stop("The posterior is infinite!")
+          if(is.nan(Mo0[[1]])) stop("The posterior was not a number!")
+          if(is.na(Mo0[[2]])) stop("The deviance is a missing value!")
+          if(is.infinite(Mo0[[2]])) stop("The deviance is infinite!")
+          if(is.nan(Mo0[[2]])) stop("The deviance is not a number!")
+          if(sum(is.na(Mo0[[3]])) > 0) stop("Monitored variable(s) have a missing value!")
+          if(sum(is.infinite(Mo0[[3]])) > 0) stop("Monitored variable(s) have an infinite value!")
+          if(sum(is.nan(Mo0[[3]])) > 0) stop("Monitored variable(s) include a value that is not a number!")
           ### Propose new parameter values
           MVN.rand <- rnorm(LIV, 0, 1)
           MVN.test <- try(MVNz <- matrix(MVN.rand,1,LIV) %*% chol(VarCov),
@@ -205,6 +208,8 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
                     }
                }
           }
+     ### Warnings (After Updating)
+     if (Acceptance == 0) cat("\nWARNING: All proposals were rejected.\n")
      ### Real Values
      thinned <- ifelse(is.na(thinned), 0, thinned)
      thinned <- ifelse(is.infinite(thinned), 0, thinned)
@@ -342,7 +347,7 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
      time2 <- proc.time()
      ### Compile Output
      cat("Creating Output\n")
-     LaplacesDemon.out <- list(Acceptance.Rate=round(Acceptance/Iterations,3),
+     LaplacesDemon.out <- list(Acceptance.Rate=round(Acceptance/Iterations,7),
           Adaptive=Adaptive,
           Algorithm=Algorithm,
           Call=match.call(),
